// Programmierung verteilter und mobiler Anwendungen
// Prof. Dr. Carsten Vogt
// Fachhochschule Köln, Institut für Nachrichtentechnik
// Stand: 3.2.2015

/* This is a very basic example for how to use a navigation drawer.
   The drawer allows to select a photo from a list, which is then displayed in the main view.
   A more extensive example can be found at http://developer.android.com/training/implementing-navigation/nav-drawer.html.

   Note: You might see some error messages if the support library is not properly imported.
   Then do the following:
   1.) Follow "File > Project Structure > Modules:app > Dependencies".
   2.) Mark "com.android.support... / Compile".
   3.) Click "Apply". */

package de.fhkoeln.cvogt.android.navigationdrawer;

import android.app.*;
import android.content.res.Configuration;
import android.os.Bundle;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.view.*;
import android.widget.*;

/* Basic version - navigation drawer can only be opened with a swipe gesture */

/*
public class MainActivity extends Activity {

    private DrawerLayout appLayout;  // the layout for this app, i.e. for the drawer and the main view displaying the photos
    private ListView drawerListView; // the ListView displayed in the navigation drawer

    @Override
    protected void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);  // content view = navigation drawer with a corresponding view displaying the photos

        // initialize the attributes of this MainActivity object
        appLayout = (DrawerLayout) findViewById(R.id.drawer_app_layout);
        drawerListView = (ListView) findViewById(R.id.drawer_list_view);

        // initialize the list in the drawer with the names of the photos
        String photoNames[] = getResources().getStringArray(R.array.photo_names);
        drawerListView.setAdapter(new ArrayAdapter<String>(this, R.layout.drawer_list_item, photoNames));

        // assign the listener to be called when a drawer item is clicked
        drawerListView.setOnItemClickListener(new DrawerItemClickListener());

        // set a shadow to blur the current photo view while the drawer is open
        appLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);

        // display the first photo
        showPhoto(0);

    }

    // listener to react on a click on an item in the navigation drawer

    private class DrawerItemClickListener implements ListView.OnItemClickListener {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
            showPhoto(position);
        }
    }

    // method to display a photo

    private void showPhoto(int position) {

        // get the number of the photo to be displayed
        Bundle argsForFragment = new Bundle();
        argsForFragment.putInt("photo_number", position);

        // prepare the fragment to be displayed
        Fragment fragment = new PhotoFragment();
        fragment.setArguments(argsForFragment);

        // display the fragment with the photo
        getFragmentManager().beginTransaction().replace(R.id.layout_main_view, fragment).commit();

        // close the navigation drawer
        appLayout.closeDrawer(drawerListView);

    }

    // fragment to display a photo in the main view

    public static class PhotoFragment extends Fragment {

        public PhotoFragment() { } // all Fragment subclasses must have an empty constructor

        // method called by the system when the fragment shall be displayed

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {

            // create the view, as defined by the layout specified in photo_display.xml
            View view = inflater.inflate(R.layout.photo_display, container, false);

            // get the Id of the photo to be displayed
            int photoNumber = getArguments().getInt("photo_number");
            String photoName = getResources().getStringArray(R.array.photo_names)[photoNumber];
            int photoId = getResources().getIdentifier(photoName.toLowerCase(),"drawable", getActivity().getPackageName());

            // display the photo
            ((ImageView) view.findViewById(R.id.photoImageView)).setImageResource(photoId);
            return view;
        }
    }
}

*/

/* Extended version - navigation drawer can be opened with a swipe gesture or a click in the action bar */

public class MainActivity extends Activity {

    private DrawerLayout appLayout;  // the layout for this app, i.e. for the drawer and the main view displaying the photos
    private ListView drawerListView; // the ListView displayed in the navigation drawer
    private ActionBarDrawerToggle drawerToggle; // the drawer toggle connecting the action bar with the drawer

    @Override
    protected void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);  // content view = navigation drawer with a corresponding view displaying the photos

        // initialize the attributes of this MainActivity object
        appLayout = (DrawerLayout) findViewById(R.id.drawer_app_layout);
        drawerListView = (ListView) findViewById(R.id.drawer_list_view);

        // initialize the list in the drawer with the names of the photos
        String photoNames[] = getResources().getStringArray(R.array.photo_names);
        drawerListView.setAdapter(new ArrayAdapter<String>(this, R.layout.drawer_list_item, photoNames));

        // assign the listener to be called when a drawer item is clicked
        drawerListView.setOnItemClickListener(new DrawerItemClickListener());

        // set a shadow to blur the current photo view while the drawer is open
        appLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);

        // set the title in the action bar
        ActionBar actionBar = getActionBar();
        actionBar.setTitle(R.string.drawer_title);

        // enable the app icon in the action bar to toggle the drawer
        actionBar.setDisplayHomeAsUpEnabled(true);
        actionBar.setHomeButtonEnabled(true);

        // specify an ActionBarDrawerToggle to connect the navigation drawer with the app icon in the action bar
        drawerToggle = new ActionBarDrawerToggle(this,appLayout,0,0);
            // if you work with support library v4: drawerToggle = new ActionBarDrawerToggle(this,appLayout,R.drawable.ic_drawer,0,0);
        appLayout.setDrawerListener(drawerToggle);

        // display the first photo
        showPhoto(0);

    }

    @Override
    protected void onPostCreate(Bundle savedInstanceState) {
        super.onPostCreate(savedInstanceState);
        drawerToggle.syncState();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        drawerToggle.onConfigurationChanged(newConfig);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main_menu,menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (drawerToggle.onOptionsItemSelected(item))
            // indicates that the ActionBarDrawerToggle will open or close the drawer
            return true;
        return super.onOptionsItemSelected(item);
    }

    // listener to react on a click on an item in the navigation drawer

    private class DrawerItemClickListener implements ListView.OnItemClickListener {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
            showPhoto(position);
        }
    }

    // method to display a photo

    private void showPhoto(int position) {

        // get the number of the photo to be displayed
        Bundle argsForFragment = new Bundle();
        argsForFragment.putInt("photo_number", position);

        // prepare the fragment to be displayed
        Fragment fragment = new PhotoFragment();
        fragment.setArguments(argsForFragment);

        // display the fragment with the photo
        getFragmentManager().beginTransaction().replace(R.id.layout_main_view, fragment).commit();

        // close the navigation drawer
        appLayout.closeDrawer(drawerListView);

    }

    // fragment to display a photo in the main view

    public static class PhotoFragment extends Fragment {

        public PhotoFragment() { } // all Fragment subclasses must have an empty constructor

        // method called by the system when the fragment shall be displayed

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {

            // create the view, as defined by the layout specified in photo_display.xml
            View view = inflater.inflate(R.layout.photo_display, container, false);

            // get the Id of the photo to be displayed
            int photoNumber = getArguments().getInt("photo_number");
            String photoName = getResources().getStringArray(R.array.photo_names)[photoNumber];
            int photoId = getResources().getIdentifier(photoName.toLowerCase(),"drawable", getActivity().getPackageName());

            // display the photo
            ((ImageView) view.findViewById(R.id.photoImageView)).setImageResource(photoId);
            return view;
        }

    }

}



